==> abg_utils-3.2.9.tar.gz: lib/src/model/local_settings.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:abg_utils/abg_utils.dart';
import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';

getLocalSettings() async {
  dprint("getLocalSettings");
  try{
    var directory = await getApplicationDocumentsDirectory();
    var directoryPath = directory.path;
    var _file = File('$directoryPath/localSettings.json');
    if (await _file.exists()){
      final contents = await _file.readAsString();
      var data = json.decode(contents);
      dprint("getLocalSettings $data");
      localSettings = LocalSettings.fromJson(data);
      //dprint("productsLastTime: ${localSettings.productsLastTime}");
    }
  }catch(ex){
    print("exception getTheme $ex");
  }
}

LocalSettings localSettings = LocalSettings.createEmpty();

class LocalSettings{

  String locale = "";
  double mapLat = 0;
  double mapLng = 0;
  double mapZoom = 12;
  // String currentAddress;
  String hint;
  bool darkMode = false;
  DateTime productsLastTime;
  bool showOnBoard = true;
  //
  String logo = "";
  Color mainColor = Color(0xff69c4ff);

  LocalSettings({
    this.locale = "",
    this.mapLat = 0,
    this.mapLng = 0,
    this.mapZoom = 12,
    // this.currentAddress = "",
    this.hint = "",
    this.darkMode = false,
    required this.productsLastTime,
    this.showOnBoard = true,
    this.logo = "",
    this.mainColor = const Color(0xff69c4ff),
  });

  Map<String, dynamic> toJson() => {
    'locale' : locale,
    'mapLat' : mapLat,
    'mapLng' : mapLng,
    'mapZoom' : mapZoom,
    // 'currentAddress' : currentAddress,
    'hint' : hint,
    'darkMode' : darkMode,
    'productsLastTime' : productsLastTime.toString(),
    'showOnBoard': showOnBoard,
    //
    'logo': logo,
    'mainColor': mainColor.value.toString(),
  };

  factory LocalSettings.createEmpty(){
    return LocalSettings(productsLastTime: DateTime.now());
  }

  factory LocalSettings.fromJson(Map<String, dynamic> data){
    List<String> _address = [];
    if (data['address'] != null)
      for (dynamic key in data['address'])
        _address.add(key.toString());
    return LocalSettings(
      locale : (data["locale"] != null) ? data["locale"]: "",
      mapLat : (data["mapLat"] != null) ? toDouble(data["mapLat"].toString()): 0,
      mapLng : (data["mapLng"] != null) ? toDouble(data["mapLng"].toString()): 0,
      mapZoom : (data["mapZoom"] != null) ? toDouble(data["mapZoom"].toString()): 0,
      // currentAddress : (data["currentAddress"] != null) ? data["currentAddress"]: "",
      hint : (data["hint"] != null) ? data["hint"]: "",
      darkMode: (data["darkMode"] != null) ? data["darkMode"]: false,
      productsLastTime : (data["productsLastTime"] != null) ? DateTime.parse(data["productsLastTime"]) : DateTime(1000),
      showOnBoard: (data["showOnBoard"] != null) ? data["showOnBoard"]: true,
      //
      logo : (data["logo"] != null) ? data["logo"]: "",
      mainColor: (data["mainColor"] != null) ? toColor(data["mainColor"]) : Color(0xff69c4ff),
    );
  }

  setShowOnBoard(bool val){
    showOnBoard = val;
    _save();
  }

  setLocal(String value){
    locale = value;
    dprint("LocalSettings setLocal $value");
    _save();
  }

  setMap(double lat, double lng, double zoom){
    mapLat = lat;
    mapLng = lng;
    mapZoom = zoom;
    dprint("LocalSettings setMap");
    _save();
  }

  // setCurrentAddress(String val){
  //   currentAddress = val;
  //   dprint("LocalSettings setCurrentAddress _cur=$val");
  //   _save();
  // }

  setHint(String val){
    hint = val;
    dprint("LocalSettings setHint val=$val");
    _save();
  }

  setDarkMode(bool val){
    darkMode = val;
    dprint("LocalSettings setDarkMode val=$val");
    _save();
  }

  setLogo(String val){
    logo = val;
    dprint("LocalSettings setLogo val=$val");
    _save();
  }

  setMainColor(Color val){
    mainColor = val;
    dprint("LocalSettings mainColor val=$val");
    _save();
  }

  setProductLastTime(DateTime _productsLastTime){
    productsLastTime = _productsLastTime;
    dprint("productsLastTime: $productsLastTime");
    _save();
  }

  _save() async {
    var directory = await getApplicationDocumentsDirectory();
    var directoryPath = directory.path;
    await File('$directoryPath/localSettings.json').writeAsString(json.encode(toJson()));
  }
}

==> abg_utils-3.4.2.tar.gz: lib/src/model/local_settings.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:abg_utils/abg_utils.dart';
import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';

getLocalSettings() async {
  dprint("getLocalSettings");
  try{
    var directory = await getApplicationDocumentsDirectory();
    var directoryPath = directory.path;
    var _file = File('$directoryPath/localSettings.json');
    if (await _file.exists()){
      final contents = await _file.readAsString();
      var data = json.decode(contents);
      dprint("getLocalSettings $data");
      localSettings = LocalSettings.fromJson(data);
      //dprint("productsLastTime: ${localSettings.productsLastTime}");
    }
  }catch(ex){
    print("exception getTheme $ex");
  }
}

LocalSettings localSettings = LocalSettings.createEmpty();

class LocalSettings{

  String locale = "";
  double mapLat = 0;
  double mapLng = 0;
  double mapZoom = 12;
  String hint;
  bool darkMode = false;
  bool showOnBoard = true;
  //
  String logo = "";
  Color mainColor = Color(0xff69c4ff);

  LocalSettings({
    this.locale = "",
    this.mapLat = 0,
    this.mapLng = 0,
    this.mapZoom = 12,
    this.hint = "",
    this.darkMode = false,
    this.showOnBoard = true,
    this.logo = "",
    this.mainColor = const Color(0xff69c4ff),
  });

  Map<String, dynamic> toJson() => {
    'locale' : locale,
    'mapLat' : mapLat,
    'mapLng' : mapLng,
    'mapZoom' : mapZoom,
    // 'currentAddress' : currentAddress,
    'hint' : hint,
    'darkMode' : darkMode,
    'showOnBoard': showOnBoard,
    //
    'logo': logo,
    'mainColor': mainColor.value.toString(),
  };

  factory LocalSettings.createEmpty(){
    return LocalSettings();
  }

  factory LocalSettings.fromJson(Map<String, dynamic> data){
    List<String> _address = [];
    if (data['address'] != null)
      for (dynamic key in data['address'])
        _address.add(key.toString());
    return LocalSettings(
      locale : (data["locale"] != null) ? data["locale"]: "",
      mapLat : (data["mapLat"] != null) ? toDouble(data["mapLat"].toString()): 0,
      mapLng : (data["mapLng"] != null) ? toDouble(data["mapLng"].toString()): 0,
      mapZoom : (data["mapZoom"] != null) ? toDouble(data["mapZoom"].toString()): 0,
      // currentAddress : (data["currentAddress"] != null) ? data["currentAddress"]: "",
      hint : (data["hint"] != null) ? data["hint"]: "",
      darkMode: (data["darkMode"] != null) ? data["darkMode"]: false,
      showOnBoard: (data["showOnBoard"] != null) ? data["showOnBoard"]: true,
      //
      logo : (data["logo"] != null) ? data["logo"]: "",
      mainColor: (data["mainColor"] != null) ? toColor(data["mainColor"]) : Color(0xff69c4ff),
    );
  }

  setShowOnBoard(bool val){
    showOnBoard = val;
    _save();
  }

  setLocal(String value){
    locale = value;
    dprint("LocalSettings setLocal $value");
    _save();
  }

  setMap(double lat, double lng, double zoom){
    mapLat = lat;
    mapLng = lng;
    mapZoom = zoom;
    dprint("LocalSettings setMap");
    _save();
  }

  // setCurrentAddress(String val){
  //   currentAddress = val;
  //   dprint("LocalSettings setCurrentAddress _cur=$val");
  //   _save();
  // }

  setHint(String val){
    hint = val;
    dprint("LocalSettings setHint val=$val");
    _save();
  }

  setDarkMode(bool val){
    darkMode = val;
    dprint("LocalSettings setDarkMode val=$val");
    _save();
  }

  setLogo(String val){
    logo = val;
    dprint("LocalSettings setLogo val=$val");
    _save();
  }

  setMainColor(Color val){
    mainColor = val;
    dprint("LocalSettings mainColor val=$val");
    _save();
  }

  _save() async {
    var directory = await getApplicationDocumentsDirectory();
    var directoryPath = directory.path;
    await File('$directoryPath/localSettings.json').writeAsString(json.encode(toJson()));
  }
}
